# zirkus


## Development

To develop with this package, install it in development mode
into a virtual environment:

    cd zirkus
    pip install -e .

You can run the tests with:

    python setup.py test

or

    py.test
